#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 hls-test-utils
version:              2.2.0.0
visibility:           public
id:                   hls-test-utils-2.2.0.0-Gy61UQQudshAElnYGGUxYh
key:                  hls-test-utils-2.2.0.0-Gy61UQQudshAElnYGGUxYh
license:              Apache-2.0
copyright:            The Haskell IDE Team
maintainer:           alan.zimm@gmail.com
author:               The Haskell IDE Team
homepage:             https://github.com/haskell/haskell-language-server#readme
synopsis:             Utilities used in the tests of Haskell Language Server
description:
    Please see the README on GitHub at <https://github.com/haskell/haskell-language-server#readme>

category:             Development
abi:                  3e6f1e9542b44623273fc95e4c686bdf
exposed:              True
exposed-modules:      Test.Hls Test.Hls.Util
import-dirs:          /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.2.0.0
library-dirs:         /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.2.0.0
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/hls-test-utils-2.2.0.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-hls-test-utils
hs-libraries:         HShls-test-utils-2.2.0.0-Gy61UQQudshAElnYGGUxYh
depends:
    aeson-2.2.1.0-28ssJzlQESE12G8XLETNIx
    async-2.2.5-FIWsXw8tceP2d6lj6DHM5i base-4.18.2.1
    blaze-markup-0.8.3.0-DgyjMppLwtBJgVLsW3zIw8 bytestring-0.11.5.3
    containers-0.6.7 data-default-0.7.1.3-5y5VYR5qIF5L6R23Ybd297
    directory-1.3.8.5 extra-1.7.16-HTBQCN3DO2zH7sDTaOIuTE
    filepath-1.4.300.1 ghcide-2.2.0.0-FjpVTF3I1rW5cU3gU0U9e3
    hls-graph-2.2.0.0-3eqLjE4pkj8muHe1oW2q
    hls-plugin-api-2.2.0.0-1K2g4OQNXqu8cEEBtrrh7t
    lens-5.3.4-4Gn3x9DAN5U4gsnCQbhlSx
    lsp-2.2.0.0-7cgEV9u8DvVDcsmYHwBDED
    lsp-test-0.16.0.0-3l5nD9oMZRyDda6cjOYUqc
    lsp-types-2.0.2.0-CI3ure8GvXR2MROqXRVGWB
    row-types-1.0.1.2-Lr5q0xOaxVeGuQGdaVUK7F
    tasty-1.5.2-LwEXSl8ldkFLRyZHMQwKn1
    tasty-expected-failure-0.12.3-GTciVGqNQSMAHK9Gm3LbbB
    tasty-golden-2.3.5-Bh3RJw4CrEpJkp4djoUg9p
    tasty-hunit-0.10.2-ClyqywvO9zYLRa2uIpb5f6
    tasty-rerun-1.1.20-Jwort0MJLGTBmk9M5cOWsY
    temporary-1.3-vYPArfKPXAFeZtaQhptNG text-2.0.2
    unordered-containers-0.2.20.1-ZzaTCzIdz8BWoPLHKXAc8

haddock-interfaces:
    /usr/share/doc/haskell-hls-test-utils/html/hls-test-utils.haddock

haddock-html:         /usr/share/doc/haskell-hls-test-utils/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

